-- ----------------------------------------------------------------------
-- MySQL Migration Toolkit
-- SQL Create Script
-- ----------------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

DROP DATABASE IF EXISTS `Fahrrad_1`;
CREATE DATABASE IF NOT EXISTS `Fahrrad_1`
  CHARACTER SET utf8 COLLATE utf8_general_ci;
USE `Fahrrad_1`;
-- -------------------------------------
-- Tables

CREATE TABLE `Fahrrad_1`.`Fahrradtypen` (
  `Typnr` VARCHAR(5) NOT NULL,
  `Typbezeichnung` VARCHAR(30) NULL,
  `Kurzerlaeuterung` VARCHAR(60) NULL,
  PRIMARY KEY (`Typnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `Fahrrad_1`.`Fahrraeder` (
  `Fahrradnr` VARCHAR(5) NOT NULL,
  `Bezeichnung` VARCHAR(50) NULL,
  `Rahmennummer` VARCHAR(10) NULL,
  `Tagesmietpreis` DOUBLE(4, 2) NULL,
  `Wert` DOUBLE(6, 2) NULL,
  `Kaufdatum` DATE NULL,
  `Herstellernr` VARCHAR(5) NULL,
  `Typnr` VARCHAR(5) NULL,
  PRIMARY KEY (`Fahrradnr`),
  INDEX `FahrradtypenFahrraeder` (`Typnr`),
  INDEX `HerstellerFahrraeder` (`Herstellernr`),
  CONSTRAINT `FahrradtypenFahrraeder` FOREIGN KEY `FahrradtypenFahrraeder` (`Typnr`)
    REFERENCES `Fahrrad_1`.`Fahrradtypen` (`Typnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `HerstellerFahrraeder` FOREIGN KEY `HerstellerFahrraeder` (`Herstellernr`)
    REFERENCES `Fahrrad_1`.`Hersteller` (`Herstellernr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `Fahrrad_1`.`Hersteller` (
  `Herstellernr` VARCHAR(5) NOT NULL,
  `Herstellername` VARCHAR(30) NULL,
  `Email` VARCHAR(30) NULL,
  PRIMARY KEY (`Herstellernr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `Fahrrad_1`.`Kunden` (
  `Kundennr` VARCHAR(5) NOT NULL,
  `Name` VARCHAR(30) NULL,
  `Vorname` VARCHAR(20) NULL,
  `Strasse` VARCHAR(30) NULL,
  `Ortnr` INT(10) NULL,
  `Geschlecht` VARCHAR(1) NULL,
  `Gebtag` DATE NULL,
  PRIMARY KEY (`Kundennr`),
  INDEX `WohnorteKunden` (`Ortnr`),
  CONSTRAINT `WohnorteKunden` FOREIGN KEY `WohnorteKunden` (`Ortnr`)
    REFERENCES `Fahrrad_1`.`Wohnorte` (`Ortnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `Fahrrad_1`.`Vermietungen` (
  `Mietnr` VARCHAR(5) NOT NULL,
  `Mietdatum` DATE NULL,
  `von` DATE NULL,
  `bis` DATE NULL,
  `Fahrradnr` VARCHAR(5) NULL,
  `Kundennr` VARCHAR(5) NULL,
  PRIMARY KEY (`Mietnr`),
  INDEX `FahrraederVermietungen` (`Fahrradnr`),
  INDEX `KundenVermietungen` (`Kundennr`),
  CONSTRAINT `FahrraederVermietungen` FOREIGN KEY `FahrraederVermietungen` (`Fahrradnr`)
    REFERENCES `Fahrrad_1`.`Fahrraeder` (`Fahrradnr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT,
  CONSTRAINT `KundenVermietungen` FOREIGN KEY `KundenVermietungen` (`Kundennr`)
    REFERENCES `Fahrrad_1`.`Kunden` (`Kundennr`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE `Fahrrad_1`.`Wohnorte` (
  `Ortnr` INT(10) NOT NULL,
  `PLZ` VARCHAR(5) NULL,
  `Ort` VARCHAR(50) NULL,
  PRIMARY KEY (`Ortnr`)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;



SET FOREIGN_KEY_CHECKS = 1;

-- ----------------------------------------------------------------------
-- EOF

